How-to Guides
=============

This section contains guides on how to do specific things with CSET.

.. toctree::
    :maxdepth: 1

    common-errors
    operator-recipes
    workflow-installation
    add-diagnostic
